@@ -30,10 +30,14 @@ impl Store for Redis {
         Some(svec!["redis-server", "--requirepass", self.password])
     }
 
-    fn reset_cmd(&self) -> Vec<String> {
+    fn drop_cmd(&self) -> Vec<String> {
         svec!["redis-cli", "-n", self.database, "flushdb"]
     }
 
+    fn init_db_cmd(&self) -> Vec<String> {
+        self.drop_cmd()
+    }
+
     fn ping_cmd(&self) -> Vec<String> {
         svec!["redis-cli", "-c", "ping"]
     }
