@@ -51,7 +51,7 @@ pub struct BackendOpt {
 #[strum(serialize_all = "snake_case")]
 #[serde(rename_all(deserialize = "snake_case"))]
 pub enum Backend {
-    /// Redis store
+    /// Redis playground
     Redis {
         #[clap(short = 'P', long, default_value = "6379")]
         port: u16,
@@ -62,7 +62,7 @@ pub enum Backend {
         #[clap(short, long, default_value = "oomplay")]
         database: u32,
     },
-    /// Postgres store
+    /// Postgres playground
     Postgres {
         #[clap(short = 'P', long, default_value = "5432")]
         port: u16,
@@ -76,7 +76,7 @@ pub enum Backend {
         #[clap(short, long, default_value = "oomplay")]
         database: String,
     },
-    /// Mysql store
+    /// MySQL playground
     Mysql {
         #[clap(short = 'P', long, default_value = "3306")]
         port: u16,
@@ -90,6 +90,11 @@ pub enum Backend {
         #[clap(short, long, default_value = "oomplay")]
         database: String,
     },
+    /// DynamoDB playground
+    Dynamodb {
+        #[clap(short = 'P', long, default_value = "4566")]
+        port: u16,
+    },
 }
 
 pub type BackendMap = HashMap<String, Backend>;
